@@ -55,13 +55,25 @@ class JinjaStaticRenderer():
 
         var_path=os.path.dirname(self.config['compiled_templates_file'])
 
+
+        if self.config["verbose"] == True:
+            print "Ensure directory exists: \033[34m%s\033[0m" % (var_path)
+            print "Ensure directory exists: \033[34m%s\033[0m" % (config['output_dir'])
+
         self.ensure_dir(var_path)
         self.ensure_dir(config['output_dir'])
 
-        self.env.compile_templates(self.config['compiled_templates_file'])
+        self.env.compile_templates(
+            self.config['compiled_templates_file'],
+            ignore_errors=False
+            )
+
+        if self.config["verbose"] == True:
+            print "Loading templates from: \033[34m%s\033[0m" % (config['templates_dir'])
+            print "Compile templates to .zip: \033[32m%s\033[0m" % (self.config['compiled_templates_file'])
 
         # This lets us have bespoke template pages in the input dir too. 
-        self.env.loader = FileSystemLoader(self.config['templates_dir'])
+        # self.env.loader = FileSystemLoader(self.config['templates_dir'])
 
     # def get_template_mtimes(self, config):
     #     """
@@ -109,9 +121,13 @@ class JinjaStaticRenderer():
             try: 
                 ast = self.env.parse(self.env.loader.get_source(self.env, template))
                 self.template_trees[template] = list(meta.find_referenced_templates(ast))
+                
             except:
                 self.template_trees[template] = list()
 
+            if self.config["verbose"] == True:
+                print "\033[34m%s\033[0m references templates \033[32m%s\033[0m" % (template, self.template_trees[template])
+
         return self.template_trees[template]
 
     def get_global_vars(self):
@@ -170,7 +186,9 @@ class JinjaStaticRenderer():
             template_object = env.get_template(template)
         except:
             print "\033[1;91mCouldn't parse `%s`. Check the template for errors \033[0;37m" % (template)
-            traceback.print_exc()
+            
+            if self.config["verbose"] == True:
+                traceback.print_exc()
             print "\033[0m"
             return [new_file_path, 0, template]
 
@@ -187,8 +205,8 @@ class JinjaStaticRenderer():
                 force_render = 1
                 ref_template_mtime = time
 
-
-        print "Last built at: %s, page mtime: %s, templ mtime: %s, ref-templates mtime: %s" % (last_build_time, page.get_modified_time(), template_modified_time, ref_template_mtime)
+        if self.config["verbose"] == True:
+            print "\033[34m%s\033[37m last built at: %s, page mtime: %s, templ mtime: %s, ref-templates mtime: %s\033[0m" % (page.file_path, last_build_time, page.get_modified_time(), template_modified_time, ref_template_mtime)
 
 
         file_did_render = 0
@@ -217,6 +235,9 @@ class JinjaStaticRenderer():
         for item in items:
             print>>file, "%s, %s, %s" % (item[0], item[2], item[1])
 
+        if self.config["verbose"] == True:
+            print "Wrote log to: \033[32m%s\033[0m" % (self.config['compiled_templates_log'])
+
     def get_last_build_time(self):
         """
         Get the last run time. Useful for checking what stuff's changed since we
